@@ -2,7 +2,7 @@
 
 # EnPT, EnMAP Processing Tool - A Python package for pre-processing of EnMAP Level-1B data
 #
-# Copyright (C) 2019  Karl Segl (GFZ Potsdam, segl@gfz-potsdam.de), Daniel Scheffler
+# Copyright (C) 2018-2021 Karl Segl (GFZ Potsdam, segl@gfz-potsdam.de), Daniel Scheffler
 # (GFZ Potsdam, danschef@gfz-potsdam.de), Niklas Bohn (GFZ Potsdam, nbohn@gfz-potsdam.de),
 # Stéphane Guillaso (GFZ Potsdam, stephane.guillaso@gfz-potsdam.de)
 #
@@ -30,6 +30,7 @@
 """EnPT process controller module."""
 
 import os
+import sys
 import tempfile
 import zipfile
 import shutil
@@ -39,6 +40,7 @@ import pickle
 from typing import Optional
 from time import time
 from datetime import timedelta
+from glob import glob
 
 from ..options.config import EnPTConfig
 from ..io.reader import L1B_Reader
@@ -84,6 +86,15 @@ class EnPT_Controller(object):
         with zipfile.ZipFile(path_zipfile, "r") as zf:
             zf.extractall(outdir)
 
+        # move the data one level up in case they are within a sub-folder in the zip file
+        if not self.cfg.is_dummy_dataformat:
+            content = glob(os.path.join(outdir, '*'))
+
+            if len(content) == 1 and os.path.isdir(content[0]):
+                for fp in glob(os.path.join(outdir, '**', '*')):
+                    shutil.move(fp, outdir)
+                shutil.rmtree(content[0])
+
         if not os.path.isdir(outdir):
             raise NotADirectoryError(outdir)
 
@@ -156,6 +167,9 @@ class EnPT_Controller(object):
         """Run all processors at once."""
         if os.getenv('IS_ENPT_GUI_TEST') != "1":
             try:
+                if os.getenv('IS_ENPT_GUI_CALL') == "1":
+                    self._write_to_stdout_stderr()
+
                 if self.cfg.log_level == 'DEBUG':
                     self._print_received_configuration()
 
@@ -200,6 +214,14 @@ class EnPT_Controller(object):
                     ),
                     outF)
 
+    @staticmethod
+    def _write_to_stdout_stderr():
+        """Write to STDOUT and STDERR to reveal Queue.name of these streams to enpt_enmapboxapp."""
+        sys.stdout.write('Connecting to EnPT STDOUT stream.\n')
+        sys.stdout.flush()
+        sys.stderr.write('Connecting to EnPT STDERR stream.\n')
+        sys.stderr.flush()
+
     def _print_received_configuration(self):
         print('EnPT Controller received the following configuration:')
         print(repr(self.cfg))
