@@ -2,7 +2,7 @@
 
 # EnPT, EnMAP Processing Tool - A Python package for pre-processing of EnMAP Level-1B data
 #
-# Copyright (C) 2019  Karl Segl (GFZ Potsdam, segl@gfz-potsdam.de), Daniel Scheffler
+# Copyright (C) 2018-2021 Karl Segl (GFZ Potsdam, segl@gfz-potsdam.de), Daniel Scheffler
 # (GFZ Potsdam, danschef@gfz-potsdam.de), Niklas Bohn (GFZ Potsdam, nbohn@gfz-potsdam.de),
 # Stéphane Guillaso (GFZ Potsdam, stephane.guillaso@gfz-potsdam.de)
 #
@@ -27,11 +27,11 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-"""
-EnPT module 'orthorectification' for transforming an EnMAP image from sensor to map geometry
+"""EnPT module 'orthorectification' for transforming an EnMAP image from sensor to map geometry
 based on a pixel- and band-wise coordinate-layer (geolayer).
 """
 
+
 from typing import Tuple, Union  # noqa: F401
 from types import SimpleNamespace
 
