@@ -2,7 +2,7 @@
 
 # EnPT, EnMAP Processing Tool - A Python package for pre-processing of EnMAP Level-1B data
 #
-# Copyright (C) 2019  Karl Segl (GFZ Potsdam, segl@gfz-potsdam.de), Daniel Scheffler
+# Copyright (C) 2018-2021 Karl Segl (GFZ Potsdam, segl@gfz-potsdam.de), Daniel Scheffler
 # (GFZ Potsdam, danschef@gfz-potsdam.de), Niklas Bohn (GFZ Potsdam, nbohn@gfz-potsdam.de),
 # Stéphane Guillaso (GFZ Potsdam, stephane.guillaso@gfz-potsdam.de)
 #
@@ -50,7 +50,7 @@ from ..spatial_transform import Geometry_Transformer, Geometry_Transformer_3D
 
 class Spatial_Optimizer(object):
     def __init__(self, config: EnPTConfig):
-        """Create an instance of Spatial_Optimizer"""
+        """Create an instance of Spatial_Optimizer."""
         self.cfg = config
         self._ref_Im: Optional[GeoArray, None] = GeoArray(self.cfg.path_reference_image)
 
@@ -113,7 +113,8 @@ class Spatial_Optimizer(object):
                           nodata=(self._ref_Im.nodata, 0),
                           footprint_poly_tgt=reproject_shapelyGeometry(self._EnMAP_Im.meta.vnir.ll_mapPoly,
                                                                        4326, self._EnMAP_band.epsg),
-                          mask_baddata_tgt=self._EnMAP_mask
+                          mask_baddata_tgt=self._EnMAP_mask,
+                          progress=self.cfg.disable_progress_bars is False
                           )
         TPG = CRL.tiepoint_grid
         # CRL.view_CoRegPoints(shapes2plot='vectors', hide_filtered=False, figsize=(20, 20),
